// $Id:$
//
//

#include "TString.h"
#include "TSystem.h"
#include "TRandom.h"
#include "TFile.h"
#include "TROOT.h"
#include "TTree.h"
#include "Riostream.h"
#include "eventclass/Event.h"

void CreateEventTree(const char *basedir, Int_t nevents, Int_t nfiles, Int_t first = 1, Bool_t split = kTRUE)
{

   TString ord = "0";

   Int_t i = first; 
   for (Int_t k = 0; k < nfiles; k++) {
      i = first + k;
      TString seed;
      seed.Form("%s_%d", ord.Data(), i);
      if (!split) seed += "_unsplit";
      gRandom->SetSeed(static_cast<UInt_t>(TMath::Hash(seed)));

      TString filename, filefriend;
      filename.Form("%s/event_tree_%s.root", basedir, seed.Data());
      filefriend.Form("%s/event_friend_%s.root", basedir, seed.Data());

      Printf("CreateEventTree: opening file %s ...", filename.Data());

      // If needed, force creation of non-existing pieces of pat
      filename += "?mkpath=1";
      filefriend += "?mkpath=1";

      TDirectory* savedir = gDirectory;

      TFile *f = TFile::Open(filename, "RECREATE");
      TFile *ff = TFile::Open(filefriend, "RECREATE");
      Printf("%p %s", ff, ff->GetName());
      savedir->cd();
      if (f->IsZombie()) break;
      if (ff->IsZombie()) break;
      
      TTree eventtree("EventTree", "Event Tree");
      eventtree.SetDirectory(f);
      eventtree.AutoSave();
      TTree eventfriend("EventFriend", "Event Friend");
      eventfriend.SetDirectory(ff);
      eventfriend.AutoSave();

      Event event;
      Event *ep = &event;
      if (split) {
         eventtree.Branch("event", "Event", &ep, 32000, 99);
      } else {
         eventtree.Branch("event", "Event", &ep, 32000, 0);
      }
      Double_t temp;
      eventfriend.Branch("temp", &temp, "temp/D");

      for (Int_t j = 0; j < nevents; j++) {
         event.Build(j,50,1);
         temp = event.GetTemperature();
         eventtree.Fill();
         eventfriend.Fill();
      }

      savedir = gDirectory;
      // Main tree
      f->cd();
      eventtree.Write(0, TObject::kOverwrite);
      eventtree.SetDirectory(0);
      f->Close();
      delete f;
      f = 0;
      // Friend tree
      ff->cd();
      eventfriend.Write(0, TObject::kOverwrite);
      eventfriend.SetDirectory(0);
      ff->Close();
      delete ff;
      ff = 0;
      savedir->cd();
   }
}
