#define SelEvt_cxx
// The class definition in SelEvt.h has been generated automatically
// by the ROOT utility TTree::MakeSelector(). This class is derived
// from the ROOT class TSelector. For more information on the TSelector
// framework see $ROOTSYS/README/README.SELECTOR or the ROOT User Manual.

// The following methods are defined in this file:
//    Begin():        called every time a loop on the tree starts,
//                    a convenient place to create your histograms.
//    SlaveBegin():   called after Begin(), when on PROOF called only on the
//                    slave servers.
//    Process():      called for each event, in this function you decide what
//                    to read and fill your histograms.
//    SlaveTerminate: called at the end of the loop on the tree, when on PROOF
//                    called only on the slave servers.
//    Terminate():    called at the end of the loop on the tree,
//                    a convenient place to draw/fit your histograms.
//
// To use this file, try the following session on your Tree T:
//
// Root > T->Process("SelEvt.C")
// Root > T->Process("SelEvt.C","some options")
// Root > T->Process("SelEvt.C+")
//

#include "SelEvt.h"
#include <TStyle.h>
#include <TH1F.h>
#include <TH1I.h>
#include <TCanvas.h>
#include "eventclass/Event.h"
#include "TClonesArray.h"



void SelEvt::Begin(TTree * /*tree*/)
{
   // The Begin() function is called at the start of the query.
   // When running with PROOF Begin() is only called on the client.
   // The tree argument is deprecated (on PROOF 0 is passed).

   TString option = GetOption();

}

void SelEvt::SlaveBegin(TTree * /*tree*/)
{
   // The SlaveBegin() function is called after the Begin() function.
   // When running with PROOF SlaveBegin() is called on each slave server.
   // The tree argument is deprecated (on PROOF 0 is passed).

   TString option = GetOption();

   fPtHist = new TH1F("pt_dist","p_{T} Distribution",100,0,5);
   fPtHist->SetDirectory(0);
   fPtHist->GetXaxis()->SetTitle("p_{T}");
   fPtHist->GetYaxis()->SetTitle("dN/p_{T}dp_{T}");

   fNTracksHist = new TH1I("ntracks_dist","N_{Tracks} per Event Distribution",100,0,100);
   fNTracksHist->SetDirectory(0);
   fNTracksHist->GetXaxis()->SetTitle("N_{Tracks}");
   fNTracksHist->GetYaxis()->SetTitle("N_{Events}");

}

Bool_t SelEvt::Process(Long64_t entry)
{
   // The Process() function is called for each entry in the tree (or possibly
   // keyed object in the case of PROOF) to be processed. The entry argument
   // specifies which entry in the currently loaded tree is to be processed.
   // It can be passed to either SelEvt::GetEntry() or TBranch::GetEntry()
   // to read either all or the required parts of the data. When processing
   // keyed objects with PROOF, the object is already loaded and is available
   // via the fObject pointer.
   //
   // This function should contain the "body" of the analysis. It can contain
   // simple or elaborate selection criteria, run algorithms on the data
   // of the event and typically fill histograms.
   //
   // The processing can be stopped by calling Abort().
   //
   // Use fStatus to set the return value of TTree::Process().
   //
   // The return value is currently not used.

//   GetEntry(entry);

   b_event_fNtrack->GetEntry(entry);

   fNTracksHist->Fill(fNtrack);

   b_fTracks_fPx->GetEntry(entry);
   b_fTracks_fPy->GetEntry(entry);

   for(Int_t j=0;j<fTracks_;j++){
      Double_t pt = TMath::Sqrt( fTracks_fPx[j]*fTracks_fPx[j] + fTracks_fPy[j]*fTracks_fPy[j]);
      fPtHist->Fill(pt,1./pt);
   }

   return kTRUE;
}

void SelEvt::SlaveTerminate()
{
   // The SlaveTerminate() function is called after all entries or objects
   // have been processed. When running with PROOF SlaveTerminate() is called
   // on each slave server.

}

void SelEvt::Terminate()
{
   // The Terminate() function is the last function to be called during
   // a query. It always runs on the client, it can be used to present
   // the results graphically or save the results to file.
 
   TCanvas* canvas = new TCanvas("can","can",800,600);
   canvas->Divide(1,2);
   canvas->cd(1);
   if (fNTracksHist) fNTracksHist->DrawCopy();
   canvas->cd(2);
   canvas->SetBorderMode(0);
   canvas->SetLogy();
   if (fPtHist) fPtHist->DrawCopy();
   else Warning("Terminate", "no pt dist found");
   canvas->cd();
   canvas->Update();

}
